==================
todecoratorfactory
==================

Overview
--------

todecoratorfactory

Installation
------------

To install ``todecoratorfactory``, you can use ``pip``. Open your terminal and run:

.. code-block:: bash

    pip install todecoratorfactory

License
-------

This project is licensed under the MIT License.

Links
-----

* `Documentation <https://pypi.org/project/todecoratorfactory>`_
* `Download <https://pypi.org/project/todecoratorfactory/#files>`_
* `Source <https://github.com/johannes-programming/todecoratorfactory>`_

Credits
-------

* Author: Johannes
* Email: `johannes-programming@mailfence.com <mailto:johannes-programming@mailfence.com>`_

Thank you for using ``todecoratorfactory``!